Method for Android and Windows
--------------------------

.. autoclass:: atx.device.mixin.DeviceMixin
    :members:


Method only for android
--------------------------

.. autoclass:: atx.device.android.AndroidDevice
    :members:

    .. attribute:: serial

        Android device serial number. **Optional**

Method only for windows
-----------------------
.. autoclass:: atx.device.windows.WindowsDevice
	:members: